"use strict";var i=function(t,r){return function(){return r||t((r={exports:{}}).exports,r),r.exports}};var s=i(function(c,e){
e.exports=Number
});var u=s();module.exports=u;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
